resolve_new_trace_column_type

Function resolve_new_trace_column_type 

pub fn resolve_new_trace_column_type(
    observed_types: impl IntoIterator<Item = ColumnDataType>,
) -> Result<Option<ColumnDataType>, TraceCoerceError>
Resolves the final datatype for a new trace column when there is no existing table schema to override the request-local observations.